[llvm-commits] CVS: llvm/utils/NightlyTest.pl

Chris Lattner lattner at cs.uiuc.edu
Sat Nov 6 13:35:54 PST 2004



Changes in directory llvm/utils:

NightlyTest.pl updated: 1.67 -> 1.68
---
Log message:

Adjust to printing user+system times instead of wall times.  Run the olden
numbers in 'stable' mode so that the numbers are more stable.


---
Diffs of the changes:  (+7 -6)

Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.67 llvm/utils/NightlyTest.pl:1.68
--- llvm/utils/NightlyTest.pl:1.67	Tue Sep 28 11:04:00 2004
+++ llvm/utils/NightlyTest.pl	Sat Nov  6 15:35:40 2004
@@ -698,9 +698,10 @@
     # Clean out previous results...
     system "$NICE gmake $MAKEOPTS clean > /dev/null 2>&1";
 
     # Run the nightly test in this directory, with LARGE_PROBLEM_SIZE enabled!
     system "gmake -k $MAKEOPTS $PROGTESTOPTS report.nightly.raw.out TEST=nightly " .
-           " LARGE_PROBLEM_SIZE=1 > /dev/null 2>&1";
+           " LARGE_PROBLEM_SIZE=1 GET_STABLE_NUMBERS=1 > /dev/null 2>&1";
     system "cp report.nightly.raw.out $OldenTestsLog";
   } else {
     system "gunzip ${OldenTestsLog}.gz";
@@ -715,10 +716,10 @@
   # totals file.
   my $WallTimeRE = "[A-Za-z0-9.: ]+\\(([0-9.]+) wall clock";
   foreach $Rec (@Records) {
-    my $rNATTime = GetRegex 'TEST-RESULT-nat-time: real\s*([.0-9m]+)', $Rec;
-    my $rCBETime = GetRegex 'TEST-RESULT-cbe-time: real\s*([.0-9m]+)', $Rec;
-    my $rLLCTime = GetRegex 'TEST-RESULT-llc-time: real\s*([.0-9m]+)', $Rec;
-    my $rJITTime = GetRegex 'TEST-RESULT-jit-time: real\s*([.0-9m]+)', $Rec;
+    my $rNATTime = GetRegex 'TEST-RESULT-nat-time: program\s*([.0-9m]+)', $Rec;
+    my $rCBETime = GetRegex 'TEST-RESULT-cbe-time: program\s*([.0-9m]+)', $Rec;
+    my $rLLCTime = GetRegex 'TEST-RESULT-llc-time: program\s*([.0-9m]+)', $Rec;
+    my $rJITTime = GetRegex 'TEST-RESULT-jit-time: program\s*([.0-9m]+)', $Rec;
     my $rOptTime = GetRegex "TEST-RESULT-compile: $WallTimeRE", $Rec;
     my $rBytecodeSize = GetRegex 'TEST-RESULT-compile: *([0-9]+)', $Rec;
     my $rMachCodeSize = GetRegex 'TEST-RESULT-jit-machcode: *([0-9]+).*bytes of machine code', $Rec;
@@ -698,9 +698,10 @@
     system "$NICE gmake $MAKEOPTS clean > /dev/null 2>&1";
 
-    # Run the nightly test in this directory, with LARGE_PROBLEM_SIZE enabled!
+    # Run the nightly test in this directory, with LARGE_PROBLEM_SIZE and
+    # GET_STABLE_NUMBERS enabled!
     system "gmake -k $MAKEOPTS $PROGTESTOPTS report.nightly.raw.out TEST=nightly " .






More information about the llvm-commits mailing list